pub struct DiffHunk {
pub from_line: usize,
pub from_count: usize,
pub to_line: usize,
pub to_count: usize,
pub changes: Vec<LineChange>,
}Expand description
A contiguous block of changes in a file diff
A hunk represents a section of the file where changes occur, along with surrounding context lines. This is similar to git’s unified diff format.
Fields
from_line: usizeStarting line number in the source file
from_count: usizeNumber of lines from the source file in this hunk
to_line: usizeStarting line number in the target file
to_count: usizeNumber of lines in the target file in this hunk
changes: Vec<LineChange>The actual line changes in this hunk